@@ -2,7 +2,6 @@ from .load_tree_files import (
     extract_decision_ponencia_and_annex_only,
     extract_statutes_details_only,
     get_annex,
-    get_generic,
     get_html,
     get_old,
     get_ponencia,
@@ -12,7 +11,6 @@ from .load_tree_files import (
 )
 from .path_to_local import (
     BASE_CONTENT,
-    DECISIONS_PATH,
     JUSTICES_PROPER,
     OLD_PATH,
     SC_PATH,
