@@ -6,6 +6,14 @@ from dotenv import find_dotenv, load_dotenv
 load_dotenv(find_dotenv())
 
 
+def get_path(env_var: str) -> Path | None:
+    if paths := os.getenv(env_var, None):
+        path = Path().home().joinpath(paths)
+        if path.exists():
+            return path
+    return None
+
+
 def get_base_directory() -> Path:
     """
     Need to setup `PATH_TO_LAWSQL` as environment variable, e.g. `code/lawsql-raw`:
@@ -24,17 +32,15 @@ def get_base_directory() -> Path:
     res = os.getenv("PATH_TO_LAWSQL", None)
     if not res:
         raise SyntaxError
-    texts = res.split("/")
     home = Path().home()
-    return home.joinpath(*texts)
+    return home.joinpath(res)
 
 
 BASE_CONTENT = get_base_directory()
-STATUTES_PATH: Path = BASE_CONTENT.joinpath("statutes")
-DECISIONS_PATH: Path = BASE_CONTENT.joinpath("decisions")
-JUSTICES_PROPER: Path = BASE_CONTENT.joinpath("justices", "list.yaml")
-SC_PATH: Path = DECISIONS_PATH.joinpath("sc")
-OLD_PATH: Path = DECISIONS_PATH.joinpath("legacy")
+STATUTES_PATH: Path = os.getenv("STATUTES", None)
+JUSTICES_PROPER: Path = os.getenv("SC_CASES", None)
+SC_PATH: Path = os.getenv("SC_CASES", None)
+OLD_PATH: Path = os.getenv("LEGACY_CASES", None)
 
 PONENCIA_HTML_FILE: str = "ponencia.html"
 ANNEX_HTML_FILE: str = "annex.html"
